import { onActivated, onBeforeUnmount, onDeactivated, onMounted } from 'vue';
import router from '/@/router';

/**
 * 页面显示/隐藏回调
 * 不管当前路由是否缓存，都可以使用此钩子
 * @param pageShow
 * @param pageHide
 * @returns
 */
export const usePageDisplay = (pageShow?: () => void, pageHide?: () => void) => {
	const currentRoute = router.currentRoute.value;
	// 当前页面是否开启路由缓存
	const isKeepAlive = currentRoute.meta.isKeepAlive ?? false;
	if (isKeepAlive) {
		onActivated(() => {
			pageShow?.();
		});

		onDeactivated(() => {
			pageHide?.();
		});
	} else {
		onMounted(() => {
			pageShow?.();
		});

		// 方便在此操作 dom，取消监听，unmounted 时 dom 已销毁
		onBeforeUnmount(() => {
			pageHide?.();
		});
	}
};
